[cfe-commits] r85076 - in /cfe/trunk: include/clang/Basic/TargetInfo.h lib/Basic/TargetInfo.cpp

Chris Lattner sabre at nondot.org
Sun Oct 25 15:49:18 PDT 2009


Author: lattner
Date: Sun Oct 25 17:49:18 2009
New Revision: 85076

URL: http://llvm.org/viewvc/llvm-project?rev=85076&view=rev
Log:
rename getTypeSigned() -> isTypeSigned() per daniel's review.

Modified:
    cfe/trunk/include/clang/Basic/TargetInfo.h
    cfe/trunk/lib/Basic/TargetInfo.cpp

Modified: cfe/trunk/include/clang/Basic/TargetInfo.h
URL: http://llvm.org/viewvc/llvm-project/cfe/trunk/include/clang/Basic/TargetInfo.h?rev=85076&r1=85075&r2=85076&view=diff

==============================================================================
--- cfe/trunk/include/clang/Basic/TargetInfo.h (original)
+++ cfe/trunk/include/clang/Basic/TargetInfo.h Sun Oct 25 17:49:18 2009
@@ -103,9 +103,9 @@
   /// enum. For example, SignedInt -> getIntWidth().
   unsigned getTypeWidth(IntType T) const;
 
   /// getTypeSigned - Return whether an integer types is signed. Returns true if
   /// the type is signed; false otherwise.
-  bool getTypeSigned(IntType T) const;
+  bool isTypeSigned(IntType T) const;
 
   /// getPointerWidth - Return the width of pointers on this target, for the
   /// specified address space.
@@ -103,9 +103,9 @@
   unsigned getTypeWidth(IntType T) const;
 
-  /// getTypeSigned - Return whether an integer types is signed. Returns true if
+  /// isTypeSigned - Return whether an integer types is signed. Returns true if
   /// the type is signed; false otherwise.

Modified: cfe/trunk/lib/Basic/TargetInfo.cpp
URL: http://llvm.org/viewvc/llvm-project/cfe/trunk/lib/Basic/TargetInfo.cpp?rev=85076&r1=85075&r2=85076&view=diff

==============================================================================
--- cfe/trunk/lib/Basic/TargetInfo.cpp (original)
+++ cfe/trunk/lib/Basic/TargetInfo.cpp Sun Oct 25 17:49:18 2009
@@ -106,9 +106,9 @@
   };
 }
 
 /// getTypeSigned - Return whether an integer types is signed. Returns true if
 /// the type is signed; false otherwise.
-bool TargetInfo::getTypeSigned(IntType T) const {
+bool TargetInfo::isTypeSigned(IntType T) const {
   switch (T) {
   default: assert(0 && "not an integer!");
   case SignedShort:
@@ -106,9 +106,9 @@
 }
 
-/// getTypeSigned - Return whether an integer types is signed. Returns true if
+/// isTypeSigned - Return whether an integer types is signed. Returns true if
 /// the type is signed; false otherwise.





More information about the cfe-commits mailing list